@@ -42,10 +42,10 @@ def get_dialect_pack(dialect_name, out_dir, version=None):
 
     if not check:
         raise IOError("the .zip file couldn't be downloaded.")
-    else:
-        # extract the zip in the current folder
-        z = zipfile.ZipFile(io.BytesIO(r.content))
-        z.extractall(path=str(out_dir))
+
+    # extract the zip in the current folder
+    z = zipfile.ZipFile(io.BytesIO(r.content))
+    z.extractall(path=str(out_dir))
 
     print(f"[INFO] Download completed!")
 
@@ -63,8 +63,12 @@ class Config:
          - Contains all the data required to adjust the text segmentation rules.
     """
 
-    def __init__(self, dialect_name=DEFAULT_DIALECT_PACK, base_path=DEFAULT_BASE_PATH):
+    def __init__(self, dialect_name=None, base_path=None):
         """Create config for given `dialect_name` and stored in `base_path`"""
+        if not dialect_name:
+            dialect_name = DEFAULT_DIALECT_PACK
+        if not base_path:
+            base_path = DEFAULT_BASE_PATH
         dialect_pack_path = get_dialect_pack(dialect_name, base_path)
         self.reset(dialect_pack_path)
 
@@ -96,6 +100,18 @@ class Config:
 
     @classmethod
     def from_path(cls, dialect_pack_path):
+        """Creates config from ``dialect_pack_path``.
+
+        Returns:
+            :class: `Config`: An instance of a Configuration object
+
+        Examples::
+
+            config = Config.from_path(path_to_dialect_pack)
+            assert config.dictionary == True
+            assert config.adjustments == True
+
+        """
         path = Path(dialect_pack_path)
         dialect_name = path.name
         base_path = path.parent
@@ -103,9 +119,11 @@ class Config:
 
     @property
     def profile(self):
+        """Returns profile name of the dialect_pack."""
         return self.dialect_pack_path.name
 
     def add_dialect_pack(self, path):
+        """"Merge given dialect_pack at `path` to current dialect_pack."""
         self.dialect_pack_path = path
         self._get_pack_component("dictionary", self.dictionary)
         self._get_pack_component("adjustments", self.adjustments)
