@@ -69,10 +69,9 @@ class Tokenize:
                         else:
                             # check if syllables is NO_POS or Non-word
                             if syls:
-                                self.add_found_word_or_non_word(
+                                c_idx = self.add_found_word_or_non_word(
                                     walker, match_data, syls, tokens
-                                )
-                                c_idx += len(syls)
+                                )# Unexpected syl skip bug fix if chunk to process is in remove word list
                                 break
                             # syllabel is not in the dictionary (Trie)
                             else:
@@ -89,10 +88,12 @@ class Tokenize:
                         found_max_match = True
                     # check for any syllables left, which are to be turned into independant tokens
                     elif syls:
-                        self.add_found_word_or_non_word(
+                        c_idx = self.add_found_word_or_non_word(
                             walker, match_data, syls, tokens
                         )
-                        c_idx += len(syls)
+                        if len(syls) == 1:
+                            c_idx += 1
+                        # c_idx += len(syls)
                         break
                     # non-syllable are turned into independant tokens
                     else:
@@ -148,7 +149,7 @@ class Tokenize:
             tokens.append(self.chunks_to_token([syls[0]], {}, ttype=w.NO_POS.name))
 
             # decrement chunk-idx for a new attempt to find a match
-            if syls:
+            if syls and syls[1:]: # Unexpected syl skip bug fix if chunk to process is in remove word list
                 c_idx -= len(syls[1:]) - 1
             if (
                 has_decremented
